@@ -19,13 +19,12 @@ def main():
         with open(config.scriptPath('..', 'semver.txt'), 'r') as fh:
             semver = fh.read().strip()
             semverText = f"Bikeshed v{semver}: "
-            if len(sys.argv) == 2 and sys.argv[1] == "--version":
-                print(semver)
-                return
     except:
+        semver = "???"
         semverText = ""
 
     argparser = argparse.ArgumentParser(description=f"{semverText}Processes spec source files into valid HTML.")
+    argparser.add_argument("--version", action="version", version=semver)
     argparser.add_argument("-q", "--quiet", dest="quiet", action="count", default=0,
                            help="Silences one level of message, least-important first.")
     argparser.add_argument("-s", "--silent", dest="silent", action="store_true",
